Parentage package
=================

Search for paternity according to ICAR recommendations
https://www.icar.org/Documents/GenoEx/ICAR%20Guidelines%20for%20Parentage%20Verification%20and%20Parentage%20Discovery%20based%20on%20SNP.pdf

https://www.icar.org/Documents/GenoEx/ICAR%20Guidelines%20for%20Parentage%20Verification%20and%20Parentage%20Discovery%20based%20on%20SNP.pdf

.. automodule:: snplib.parentage
   :members:
   :undoc-members:
   :show-inheritance:
